@@ -1,5 +1,4 @@
-fcrosC <-
-function(xdata, cont, test, log2.opt=0, trim.opt=0.25) {
+fcrosC <- function(xdata, cont, test, log2.opt=0, trim.opt=0.25) {
     n <- nrow(xdata);
     idnames <- xdata[,1];   # first column is unique ID for genes
     xcol <- colnames(xdata);
@@ -33,7 +32,7 @@ function(xdata, cont, test, log2.opt=0, trim.opt=0.25) {
     FC <- matrix(c(rep(0,n)), ncol = 1);
     fvect <- c(fmat[, 1:m])
 
-    rmat.val <- rmatCalc(fvect, n, m1, m2, rvect, FC);
+    rmat.val <- rmatCalc(fvect, n, m1, m2);
     rm(rvect);
     rmat <- matrix(rmat.val$rvectC, ncol = m1m2);
     FC <- rmat.val$FCC;
@@ -66,6 +65,6 @@ function(xdata, cont, test, log2.opt=0, trim.opt=0.25) {
     params <- c(delta,moy,std);
     params_t <- c(delta_t,moy_t,std_t);
 
-    list(idnames=idnames, FC=FC, FC2=FC2, ri=ri, p.value=p.value, 
+    list(idnames=idnames, FC=FC, FC2=FC2, ri=ri, p.value=p.value,
     f.value=f.value, bounds=bounds, params=params, params_t=params_t);
 }
