@@ -1,5 +1,4 @@
-fcrosTopN <-
-function(af, topN) {
+fcrosTopN <- function(af, topN) {
       f.value <- af$f.value;
       n <- length(f.value);
       s.fvalue <- sort(f.value, method = "sh", index.return = TRUE);
@@ -7,10 +6,10 @@ function(af, topN) {
       j <- 1;
       while ((i+j) < topN) {
             if ((1-s.fvalue$x[i+1]) > (s.fvalue$x[n-j])) {
-               i <- i+1; 
+               i <- i+1;
             } else { j <- j+1; }
       }
       alpha <- c(s.fvalue$x[i], s.fvalue$x[n-j+1]);
       index <- c(s.fvalue$ix[1:i],s.fvalue$ix[(n-j+1):n]);
       list(alpha = alpha, index = index)
-}
\ No newline at end of file
+}
